@@ -1,6 +1,6 @@
 package Sque::Job;
 {
-  $Sque::Job::VERSION = '0.008';
+  $Sque::Job::VERSION = '0.009';
 }
 use Any::Moose;
 use Any::Moose '::Util::TypeConstraints';
@@ -56,6 +56,12 @@ has payload => (
     }
 );
 
+has headers => (
+    is => 'rw',
+    isa => 'HashRef',
+    default => sub{ {} },
+);
+
 has frame => (
     is => 'ro',
     lazy => 1,
@@ -117,7 +123,7 @@ Sque::Job - Sque job container
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 ATTRIBUTES
 
